@@ -7,7 +7,7 @@ from redis import Redis as SyncRedis
 from sqlalchemy.engine import create_engine as create_sync_engine, Engine
 from sqlalchemy.ext.asyncio import create_async_engine, AsyncEngine
 from typing import Generic, Literal, Optional, TypeVar, Union, overload
-from maleo.types.base.dict import StringToAnyDict
+from maleo.types.dict import StringToAnyDict
 from ..enums import Connection
 from .additional import AdditionalConfigT, RedisAdditionalConfig
 from .connection import (
