@@ -1,3 +1,4 @@
+from abc import ABC, abstractmethod
 from pydantic import BaseModel, Field, model_validator
 from typing import Annotated, Generic, Literal, Optional, TypeVar
 from urllib.parse import quote_plus, urlencode
@@ -28,7 +29,7 @@ DatabaseT = TypeVar("DatabaseT", int, str)
 
 
 class BaseConnectionConfig(
-    BaseModel, Generic[DriverT, UsernameT, PasswordT, HostT, PortT, DatabaseT]
+    ABC, BaseModel, Generic[DriverT, UsernameT, PasswordT, HostT, PortT, DatabaseT]
 ):
     driver: DriverT = Field(..., description="Database's driver")
     username: UsernameT = Field(..., description="Database user's username")
@@ -40,9 +41,6 @@ class BaseConnectionConfig(
     database: DatabaseT = Field(..., description="Database's name")
 
     # Optional fields for different database types
-    auth_source: Annotated[
-        OptionalString, Field(None, description="Authentication database (Mongo)")
-    ] = None
     ssl: Annotated[
         OptionalBoolean, Field(None, description="Enable SSL connection")
     ] = None
@@ -111,53 +109,17 @@ class BaseConnectionConfig(
 
     def make_url(self, connection: Connection = Connection.ASYNC) -> str:
         """Build URL based on driver-specific format with async/sync support."""
-        if self.driver is Driver.POSTGRESQL:
-            return self._make_postgresql_url(connection)
-        elif self.driver is Driver.MYSQL:
-            return self._make_mysql_url(connection)
-        elif self.driver is Driver.SQLITE:
-            return self._make_sqlite_url(connection)
-        elif self.driver is Driver.MONGODB:
-            return self._make_mongodb_url()
-        elif self.driver is Driver.REDIS:
-            return self._make_redis_url()
-        elif self.driver is Driver.MSSQL:
-            return self._make_mssql_url(connection)
-        elif self.driver is Driver.ELASTICSEARCH:
-            return self._make_elasticsearch_url()
+        if self.driver in Driver:
+            return self._make_url(connection)
         else:
             # Fallback to standard format
             encoded_user = self._safe_encode_credential(self.username)
             encoded_pass = self._safe_encode_credential(self.password)
             return f"{self.driver}://{encoded_user}:{encoded_pass}@{self.host}:{self.port}/{self.database}"
 
-    def _make_postgresql_url(self, connection: Connection = Connection.ASYNC) -> str:
-        """PostgreSQL database URL format with proper async/sync drivers."""
-        raise NotImplementedError()
-
-    def _make_mysql_url(self, connection: Connection = Connection.ASYNC) -> str:
-        """MySQL database URL format with proper async/sync drivers."""
-        raise NotImplementedError()
-
-    def _make_sqlite_url(self, connection: Connection = Connection.ASYNC) -> str:
-        """SQLite URL format with async/sync support."""
-        raise NotImplementedError()
-
-    def _make_mongodb_url(self) -> str:
-        """Mongo URL format - Mongo driver handles async/sync internally."""
-        raise NotImplementedError()
-
-    def _make_redis_url(self) -> str:
-        """Redis URL format with async/sync support."""
-        raise NotImplementedError()
-
-    def _make_mssql_url(self, connection: Connection = Connection.ASYNC) -> str:
-        """SQL Server URL format with async/sync drivers."""
-        raise NotImplementedError()
-
-    def _make_elasticsearch_url(self) -> str:
-        """Elasticsearch URL format - HTTP-based, same for async/sync."""
-        raise NotImplementedError()
+    @abstractmethod
+    def _make_url(self, connection: Connection = Connection.ASYNC) -> str:
+        """URL Maker for specific database's type"""
 
     def get_driver_variants(self) -> StringToStringDict:
         """Get available driver variants for this database type."""
@@ -259,7 +221,7 @@ class MySQLConnectionConfig(
         MySQLCharset, Field(MySQLCharset.UTF8MB4, description="Character set")
     ] = MySQLCharset.UTF8MB4
 
-    def _make_mysql_url(self, connection: Connection = Connection.ASYNC) -> str:
+    def _make_url(self, connection: Connection = Connection.ASYNC) -> str:
         """MySQL database URL format with proper async/sync drivers."""
         # Choose appropriate driver based on connection type
         if connection is Connection.ASYNC:
@@ -304,7 +266,7 @@ class PostgreSQLConnectionConfig(
         Field(None, description="Application name for connection tracking"),
     ] = None
 
-    def _make_postgresql_url(self, connection: Connection = Connection.ASYNC) -> str:
+    def _make_url(self, connection: Connection = Connection.ASYNC) -> str:
         """PostgreSQL database URL format with proper async/sync drivers."""
         # Choose appropriate driver based on connection type
         if connection is Connection.ASYNC:
@@ -350,7 +312,7 @@ class SQLiteConnectionConfig(
         False
     )
 
-    def _make_sqlite_url(self, connection: Connection = Connection.ASYNC) -> str:
+    def _make_url(self, connection: Connection = Connection.ASYNC) -> str:
         """SQLite URL format with async/sync support."""
         # SQLite async/sync drivers
         if connection is Connection.ASYNC:
@@ -403,7 +365,7 @@ class SQLServerConnectionConfig(
                 )
         return self
 
-    def _make_mssql_url(self, connection: Connection = Connection.ASYNC) -> str:
+    def _make_url(self, connection: Connection = Connection.ASYNC) -> str:
         """SQL Server URL format with async/sync drivers."""
         # Choose appropriate driver based on connection type
         if connection is Connection.ASYNC:
@@ -430,6 +392,57 @@ class SQLServerConnectionConfig(
         return self.model_dump(include={"echo"}, exclude_none=True)
 
 
+class ElasticsearchConnectionConfig(
+    BaseConnectionConfig[
+        Literal[Driver.ELASTICSEARCH], OptionalString, OptionalString, str, int, str
+    ]
+):
+    driver: Literal[Driver.ELASTICSEARCH] = Driver.ELASTICSEARCH
+    port: Annotated[int, Field(9200, description="Elasticsearch port")] = 9200
+    username: Annotated[
+        OptionalString, Field(None, description="Elasticsearch username")
+    ] = None
+    password: Annotated[
+        OptionalString, Field(None, description="Elasticsearch password")
+    ] = None
+    database: Annotated[
+        str, Field("_all", description="Elasticsearch index pattern")
+    ] = "_all"
+
+    # Elasticsearch-specific options
+    scheme: Annotated[
+        ElasticsearchScheme,
+        Field(ElasticsearchScheme.HTTP, description="Connection scheme (http/https)"),
+    ] = ElasticsearchScheme.HTTP
+
+    @model_validator(mode="after")
+    def validate_https_consistency(self):
+        """Validate HTTPS and SSL consistency"""
+        if self.scheme == "https" and self.ssl is False:
+            raise ValueError("Cannot use https scheme with ssl=False")
+        return self
+
+    def _make_url(self, connection: Connection = Connection.ASYNC) -> str:
+        """Elasticsearch URL format - HTTP-based, same for async/sync."""
+        # Elasticsearch uses HTTP/HTTPS, async/sync is handled by the client library
+
+        auth_part = ""
+
+        if self.username and self.password:
+            encoded_user = self._safe_encode_credential(self.username)
+            encoded_pass = self._safe_encode_credential(self.password)
+            auth_part = f"{encoded_user}:{encoded_pass}@"
+
+        base_url = f"{self.scheme}://{auth_part}{self.host}:{self.port}"
+
+        # Elasticsearch doesn't typically use database in URL path like SQL databases
+        # The 'database' field might represent default index, but it's usually specified per request
+
+        # Add Elasticsearch-specific options as URL params if needed
+        es_options = {}
+        return base_url + self._make_options_string(es_options)
+
+
 class MongoConnectionConfig(
     BaseConnectionConfig[
         Literal[Driver.MONGODB], OptionalString, OptionalString, str, int, str
@@ -448,13 +461,13 @@ class MongoConnectionConfig(
     auth_source: Annotated[
         OptionalString, Field("admin", description="Authentication database")
     ] = "admin"
-    replica_set: Annotated[
-        OptionalString, Field(None, description="Replica set name")
-    ] = None
     read_preference: Annotated[
         Optional[MongoReadPreference],
         Field(MongoReadPreference.PRIMARY, description="Read preference"),
     ] = MongoReadPreference.PRIMARY
+    replica_set: Annotated[
+        OptionalString, Field(None, description="Replica set name")
+    ] = None
 
     @model_validator(mode="after")
     def validate_auth_consistency(self):
@@ -465,7 +478,7 @@ class MongoConnectionConfig(
             )
         return self
 
-    def _make_mongodb_url(self) -> str:
+    def _make_url(self, connection: Connection = Connection.ASYNC) -> str:
         """Mongo URL format - Mongo driver handles async/sync internally."""
         # Mongo uses the same URL format for both async and sync
         # The async/sync behavior is determined by the client library used
@@ -510,10 +523,10 @@ class RedisConnectionConfig(
         bool, Field(True, description="Decode responses to strings")
     ] = True
     max_connections: Annotated[
-        Optional[int], Field(None, ge=1, description="Max connections in pool")
+        OptionalInteger, Field(None, ge=1, description="Max connections in pool")
     ] = None
 
-    def _make_redis_url(self) -> str:
+    def _make_url(self, connection: Connection = Connection.ASYNC) -> str:
         """Redis URL format with async/sync support."""
         # Redis URL format is the same, but different libraries handle async/sync
         # redis-py for sync, aioredis for async
@@ -534,57 +547,6 @@ class RedisConnectionConfig(
         return base_url + self._make_options_string(redis_options)
 
 
-class ElasticsearchConnectionConfig(
-    BaseConnectionConfig[
-        Literal[Driver.ELASTICSEARCH], OptionalString, OptionalString, str, int, str
-    ]
-):
-    driver: Literal[Driver.ELASTICSEARCH] = Driver.ELASTICSEARCH
-    port: Annotated[int, Field(9200, description="Elasticsearch port")] = 9200
-    username: Annotated[
-        OptionalString, Field(None, description="Elasticsearch username")
-    ] = None
-    password: Annotated[
-        OptionalString, Field(None, description="Elasticsearch password")
-    ] = None
-    database: Annotated[
-        str, Field("_all", description="Elasticsearch index pattern")
-    ] = "_all"
-
-    # Elasticsearch-specific options
-    scheme: Annotated[
-        ElasticsearchScheme,
-        Field(ElasticsearchScheme.HTTP, description="Connection scheme (http/https)"),
-    ] = ElasticsearchScheme.HTTP
-
-    @model_validator(mode="after")
-    def validate_https_consistency(self):
-        """Validate HTTPS and SSL consistency"""
-        if self.scheme == "https" and self.ssl is False:
-            raise ValueError("Cannot use https scheme with ssl=False")
-        return self
-
-    def _make_elasticsearch_url(self) -> str:
-        """Elasticsearch URL format - HTTP-based, same for async/sync."""
-        # Elasticsearch uses HTTP/HTTPS, async/sync is handled by the client library
-
-        auth_part = ""
-
-        if self.username and self.password:
-            encoded_user = self._safe_encode_credential(self.username)
-            encoded_pass = self._safe_encode_credential(self.password)
-            auth_part = f"{encoded_user}:{encoded_pass}@"
-
-        base_url = f"{self.scheme}://{auth_part}{self.host}:{self.port}"
-
-        # Elasticsearch doesn't typically use database in URL path like SQL databases
-        # The 'database' field might represent default index, but it's usually specified per request
-
-        # Add Elasticsearch-specific options as URL params if needed
-        es_options = {}
-        return base_url + self._make_options_string(es_options)
-
-
 # Factory function with better type hints
 def create_connection_config(driver: Driver, **kwargs) -> BaseConnectionConfig:
     """Factory to create the appropriate connection config based on driver"""
