@@ -3,7 +3,7 @@ from typing import Annotated, Self, Set, TypeVar
 from maleo.types.dict import OptionalStringToStringDict, StringToAnyDict
 from maleo.types.integer import ListOfIntegers
 from maleo.types.string import OptionalString
-from maleo.utils.formatters.case import to_camel
+from maleo.utils.formatter import CaseFormatter
 from ..enums import PoolingStrategy
 
 
@@ -17,13 +17,26 @@ PoolingConfigT = TypeVar("PoolingConfigT", bound=BasePoolingConfig)
 class MySQLPoolingConfig(BasePoolingConfig):
     """MySQL-specific pooling configuration."""
 
-    pool_size: Annotated[
-        int, Field(8, description="Number of connections in the pool", ge=1, le=500)
-    ] = 8
+    autocommit: Annotated[bool, Field(False, description="Enable autocommit mode")] = (
+        False
+    )
+    connect_timeout: Annotated[
+        float, Field(10.0, description="Connection timeout in seconds", ge=1.0, le=60.0)
+    ] = 10.0
     max_overflow: Annotated[
         int,
         Field(15, description="Maximum number of overflow connections", ge=0, le=200),
     ] = 15
+    pool_pre_ping: Annotated[
+        bool, Field(True, description="Validate connections before use")
+    ] = True
+    pool_recycle: Annotated[
+        int,
+        Field(7200, description="Connection recycle time in seconds", ge=60, le=86_400),
+    ] = 7200
+    pool_size: Annotated[
+        int, Field(8, description="Number of connections in the pool", ge=1, le=500)
+    ] = 8
     pool_timeout: Annotated[
         float,
         Field(
@@ -33,24 +46,9 @@ class MySQLPoolingConfig(BasePoolingConfig):
             le=300.0,
         ),
     ] = 20.0
-    pool_recycle: Annotated[
-        int,
-        Field(7200, description="Connection recycle time in seconds", ge=60, le=86400),
-    ] = 7200
-    pool_pre_ping: Annotated[
-        bool, Field(True, description="Validate connections before use")
-    ] = True
     strategy: Annotated[
         PoolingStrategy, Field(PoolingStrategy.FIXED, description="Pooling strategy")
     ] = PoolingStrategy.FIXED
-    # Add autocommit to pooling since it affects connection behavior in the pool
-    autocommit: Annotated[bool, Field(False, description="Enable autocommit mode")] = (
-        False
-    )
-    # Move connect_timeout here since it's about pool connection establishment
-    connect_timeout: Annotated[
-        float, Field(10.0, description="Connection timeout in seconds", ge=1.0, le=60.0)
-    ] = 10.0
 
     @property
     def engine_kwargs_exclusions(self) -> Set[str]:
@@ -64,13 +62,25 @@ class MySQLPoolingConfig(BasePoolingConfig):
 class PostgreSQLPoolingConfig(BasePoolingConfig):
     """PostgreSQL-specific pooling configuration."""
 
-    pool_size: Annotated[
-        int, Field(10, description="Number of connections in the pool", ge=1, le=1000)
-    ] = 10
     max_overflow: Annotated[
         int,
         Field(20, description="Maximum number of overflow connections", ge=0, le=500),
     ] = 20
+    pool_pre_ping: Annotated[
+        bool, Field(True, description="Validate connections before use")
+    ] = True
+    pool_recycle: Annotated[
+        int,
+        Field(
+            3_600, description="Connection recycle time in seconds", ge=60, le=86_400
+        ),
+    ] = 3_600
+    pool_reset_on_return: Annotated[
+        bool, Field(True, description="Reset connection state on return to pool")
+    ] = True
+    pool_size: Annotated[
+        int, Field(10, description="Number of connections in the pool", ge=1, le=1_000)
+    ] = 10
     pool_timeout: Annotated[
         float,
         Field(
@@ -80,23 +90,12 @@ class PostgreSQLPoolingConfig(BasePoolingConfig):
             le=300.0,
         ),
     ] = 30.0
-    pool_recycle: Annotated[
-        int,
-        Field(3600, description="Connection recycle time in seconds", ge=60, le=86400),
-    ] = 3600
-    pool_pre_ping: Annotated[
-        bool, Field(True, description="Validate connections before use")
-    ] = True
-    # Keep strategy and prepared_statement_cache_size as they're pooling-related
+    prepared_statement_cache_size: Annotated[
+        int, Field(100, description="Prepared statement cache size", ge=0, le=10_000)
+    ] = 100
     strategy: Annotated[
         PoolingStrategy, Field(PoolingStrategy.DYNAMIC, description="Pooling strategy")
     ] = PoolingStrategy.DYNAMIC
-    prepared_statement_cache_size: Annotated[
-        int, Field(100, description="Prepared statement cache size", ge=0, le=10000)
-    ] = 100
-    pool_reset_on_return: Annotated[
-        bool, Field(True, description="Reset connection state on return to pool")
-    ] = True
 
     @model_validator(mode="after")
     def validate_overflow(self) -> Self:
@@ -120,29 +119,27 @@ class PostgreSQLPoolingConfig(BasePoolingConfig):
 class SQLitePoolingConfig(BasePoolingConfig):
     """SQLite-specific pooling configuration."""
 
+    busy_timeout: Annotated[
+        int,
+        Field(30_000, description="Busy timeout in milliseconds", ge=1_000, le=300_000),
+    ]
+    max_overflow: Annotated[
+        int, Field(5, description="Maximum overflow connections", ge=0, le=20)
+    ] = 5
     pool_size: Annotated[
         int,
         Field(1, description="Number of connections (limited for SQLite)", ge=1, le=10),
     ] = 1
-    max_overflow: Annotated[
-        int, Field(5, description="Maximum overflow connections", ge=0, le=20)
-    ] = 5
     pool_timeout: Annotated[
         float, Field(30.0, description="Timeout in seconds", ge=1.0, le=300.0)
     ] = 30.0
-    # SQLite-specific pooling options
     wal_mode: Annotated[
         bool, Field(True, description="Enable WAL mode for better concurrency")
     ] = True
-    busy_timeout: Annotated[
-        int,
-        Field(30000, description="Busy timeout in milliseconds", ge=1000, le=300000),
-    ]
 
     @property
     def engine_kwargs_exclusions(self) -> Set[str]:
         return {
-            "strategy",
             "wal_mode",
             "busy_timeout",
         }
@@ -155,13 +152,35 @@ class SQLitePoolingConfig(BasePoolingConfig):
 class SQLServerPoolingConfig(BasePoolingConfig):
     """SQL Server-specific pooling configuration."""
 
-    pool_size: Annotated[
-        int, Field(10, description="Number of connections in the pool", ge=1, le=500)
+    command_timeout: Annotated[
+        int, Field(30, description="Command timeout in seconds", ge=1, le=3_600)
     ]
+    connection_timeout: Annotated[
+        int, Field(30, description="Connection timeout in seconds", ge=1, le=300)
+    ] = 30
+    encrypt: Annotated[bool, Field(True, description="Encrypt connection")] = True
     max_overflow: Annotated[
         int,
         Field(20, description="Maximum number of overflow connections", ge=0, le=200),
     ] = 20
+    packet_size: Annotated[
+        int,
+        Field(
+            4_096, description="Network packet size", ge=512, le=32_768, multiple_of=256
+        ),
+    ] = 4_096
+    pool_pre_ping: Annotated[
+        bool, Field(True, description="Validate connections before use")
+    ] = True
+    pool_recycle: Annotated[
+        int,
+        Field(
+            3_600, ge=60, le=86_400, description="Connection recycle time in seconds"
+        ),
+    ] = 3_600
+    pool_size: Annotated[
+        int, Field(10, description="Number of connections in the pool", ge=1, le=500)
+    ]
     pool_timeout: Annotated[
         float,
         Field(
@@ -171,31 +190,12 @@ class SQLServerPoolingConfig(BasePoolingConfig):
             le=300.0,
         ),
     ] = 30.0
-    pool_recycle: Annotated[
-        int,
-        Field(3600, ge=60, le=86400, description="Connection recycle time in seconds"),
-    ] = 3600
-    pool_pre_ping: Annotated[
-        bool, Field(True, description="Validate connections before use")
-    ] = True
     strategy: Annotated[
         PoolingStrategy, Field(PoolingStrategy.DYNAMIC, description="Pooling strategy")
     ] = PoolingStrategy.DYNAMIC
-    # SQL Server-specific pooling settings
-    connection_timeout: Annotated[
-        int, Field(30, description="Connection timeout in seconds", ge=1, le=300)
-    ] = 30
-    command_timeout: Annotated[
-        int, Field(30, description="Command timeout in seconds", ge=1, le=3600)
-    ]
-    packet_size: Annotated[
-        int, Field(4096, description="Network packet size", ge=512, le=32767)
-    ] = 4096
     trust_server_certificate: Annotated[
         bool, Field(False, description="Trust server certificate")
     ] = False
-    # Move encrypt here since it affects connection pool behavior
-    encrypt: Annotated[bool, Field(True, description="Encrypt connection")] = True
 
     @model_validator(mode="after")
     def validate_overflow(self) -> Self:
@@ -220,25 +220,30 @@ class SQLServerPoolingConfig(BasePoolingConfig):
 class ElasticsearchPoolingConfig(BasePoolingConfig):
     """Elasticsearch-specific pooling configuration."""
 
-    # Connection pool settings
+    block: Annotated[bool, Field(False, description="Block when pool is full")] = False
+    ca_certs: Annotated[
+        OptionalString, Field(None, description="Path to CA certificates")
+    ] = None
+    connections_per_node: Annotated[
+        int, Field(10, description="Connections per Elasticsearch node", ge=1, le=50)
+    ]
+    dead_timeout: Annotated[
+        float, Field(60.0, description="Dead node timeout in seconds", ge=5.0, le=600.0)
+    ] = 60.0
+    headers: Annotated[
+        OptionalStringToStringDict,
+        Field(None, description="Default headers for requests"),
+    ] = None
+    http_compress: Annotated[
+        bool, Field(True, description="Enable HTTP compression")
+    ] = True
+    max_retries: Annotated[
+        int, Field(3, description="Maximum number of retries", ge=0, le=10)
+    ]
     maxsize: Annotated[
         int,
         Field(25, description="Maximum number of connections in pool", ge=1, le=100),
     ]
-    connections_per_node: Annotated[
-        int, Field(10, description="Connections per Elasticsearch node", ge=1, le=50)
-    ]
-
-    # Timeout settings
-    timeout: Annotated[
-        float, Field(10.0, description="Request timeout in seconds", ge=1.0, le=300.0)
-    ]
-    max_retries: Annotated[
-        int, Field(3, description="Maximum number of retries", ge=0, le=10)
-    ]
-    retry_on_timeout: Annotated[bool, Field(False, description="Retry on timeout")] = (
-        False
-    )
     retry_on_status: Annotated[
         ListOfIntegers,
         Field(
@@ -246,27 +251,15 @@ class ElasticsearchPoolingConfig(BasePoolingConfig):
             description="HTTP status codes to retry on",
         ),
     ] = [502, 503, 504]
-
-    # Connection behavior (move from connection config)
-    http_compress: Annotated[
-        bool, Field(True, description="Enable HTTP compression")
-    ] = True
+    retry_on_timeout: Annotated[bool, Field(False, description="Retry on timeout")] = (
+        False
+    )
+    timeout: Annotated[
+        float, Field(10.0, description="Request timeout in seconds", ge=1.0, le=300.0)
+    ]
     verify_certs: Annotated[
         bool, Field(True, description="Verify SSL certificates")
     ] = True
-    ca_certs: Annotated[
-        OptionalString, Field(None, description="Path to CA certificates")
-    ] = None
-
-    # Advanced pool settings
-    block: Annotated[bool, Field(False, description="Block when pool is full")] = False
-    headers: Annotated[
-        OptionalStringToStringDict,
-        Field(None, description="Default headers for requests"),
-    ] = None
-    dead_timeout: Annotated[
-        float, Field(60.0, description="Dead node timeout in seconds", ge=5.0, le=600.0)
-    ] = 60.0
 
     @model_validator(mode="after")
     def validate_overflow(self) -> Self:
@@ -291,8 +284,38 @@ class ElasticsearchPoolingConfig(BasePoolingConfig):
 class MongoPoolingConfig(BasePoolingConfig):
     """Mongo-specific pooling configuration."""
 
-    model_config = ConfigDict(alias_generator=to_camel)
+    model_config = ConfigDict(alias_generator=CaseFormatter.to_camel)
 
+    connect_timeout_ms: Annotated[
+        int,
+        Field(
+            20_000,
+            alias="connectTimeoutMS",
+            description="Connection timeout in milliseconds",
+            ge=1_000,
+            le=300_000,
+        ),
+    ] = 20_000
+    max_connecting: Annotated[
+        int,
+        Field(
+            2,
+            alias="maxConnecting",
+            description="Maximum number of concurrent connection attempts",
+            ge=1,
+            le=10,
+        ),
+    ] = 2
+    max_idle_time_ms: Annotated[
+        int,
+        Field(
+            600_000,
+            alias="maxIdleTimeMS",
+            description="Max idle time in milliseconds",
+            ge=1_000,
+            le=3_600_000,
+        ),
+    ] = 600_000
     max_pool_size: Annotated[
         int,
         Field(
@@ -313,46 +336,16 @@ class MongoPoolingConfig(BasePoolingConfig):
             le=100,
         ),
     ] = 0
-    max_idle_time_ms: Annotated[
-        int,
-        Field(
-            600000,
-            alias="maxIdleTimeMS",
-            description="Max idle time in milliseconds",
-            ge=1000,
-            le=3600000,
-        ),
-    ] = 600000
-    connect_timeout_ms: Annotated[
-        int,
-        Field(
-            20000,
-            alias="connectTimeoutMS",
-            description="Connection timeout in milliseconds",
-            ge=1000,
-            le=300000,
-        ),
-    ] = 20000
     server_selection_timeout_ms: Annotated[
         int,
         Field(
-            30000,
+            30_000,
             alias="serverSelectionTimeoutMS",
             description="Server selection timeout",
-            ge=1000,
-            le=300000,
+            ge=1_000,
+            le=300_000,
         ),
-    ] = 30000
-    max_connecting: Annotated[
-        int,
-        Field(
-            2,
-            alias="maxConnecting",
-            description="Maximum number of concurrent connection attempts",
-            ge=1,
-            le=10,
-        ),
-    ] = 2
+    ] = 30_000
 
     @property
     def client_kwargs(self) -> StringToAnyDict:
@@ -362,28 +355,28 @@ class MongoPoolingConfig(BasePoolingConfig):
 class RedisPoolingConfig(BasePoolingConfig):
     """Redis-specific pooling configuration."""
 
-    max_connections: Annotated[
-        int,
-        Field(50, description="Maximum number of connections in pool", ge=1, le=1000),
-    ] = 50
-    retry_on_timeout: Annotated[
-        bool, Field(True, description="Retry on connection timeout")
+    connection_timeout: Annotated[
+        float, Field(5.0, description="Connection timeout in seconds", ge=1.0, le=60.0)
+    ] = 5.0
+    decode_responses: Annotated[
+        bool, Field(True, description="Decode responses to strings")
     ] = True
     health_check_interval: Annotated[
         int, Field(30, description="Health check interval in seconds", ge=5, le=300)
     ] = 30
-    connection_timeout: Annotated[
-        float, Field(5.0, description="Connection timeout in seconds", ge=1.0, le=60.0)
-    ] = 5.0
+    max_connections: Annotated[
+        int,
+        Field(50, description="Maximum number of connections in pool", ge=1, le=1_000),
+    ] = 50
+    retry_on_timeout: Annotated[
+        bool, Field(True, description="Retry on connection timeout")
+    ] = True
     socket_timeout: Annotated[
         float, Field(5.0, description="Socket timeout in seconds", ge=1.0, le=60.0)
     ] = 5.0
     socket_keepalive: Annotated[
         bool, Field(True, description="Enable TCP keepalive")
     ] = True
-    decode_responses: Annotated[
-        bool, Field(True, description="Decode responses to strings")
-    ] = True
 
     @property
     def client_kwargs_exclusions(self) -> Set[str]:
