@@ -30,7 +30,7 @@ from maleo.schemas.operation.system import (
 )
 from maleo.schemas.response import NoDataResponse
 from maleo.schemas.security.authentication import OptionalAnyAuthentication
-from maleo.schemas.security.authorization import OptionalAuthorization
+from maleo.schemas.security.authorization import OptionalAnyAuthorization
 from maleo.schemas.security.impersonation import OptionalImpersonation
 from maleo.types.uuid import OptionalUUID
 from ..config import (
@@ -48,9 +48,10 @@ from ..config import (
 from ..enums import Connection
 from ..types import DeclarativeBaseT
 from .client import (
-    AsyncClientT,
-    SyncClientT,
-    ClientManager,
+    ElasticsearchClientManager,
+    MongoClientManager,
+    RedisClientManager,
+    ClientManagerT,
 )
 from .engine import EngineManager
 from .session import SessionManager
@@ -83,7 +84,7 @@ class Manager(ABC, Generic[ConfigT]):
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ) -> bool:
         pass
@@ -94,7 +95,7 @@ class Manager(ABC, Generic[ConfigT]):
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ) -> bool:
         pass
@@ -137,7 +138,7 @@ class SQLManager(Manager[SQLConfigT], Generic[SQLConfigT, DeclarativeBaseT]):
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ) -> bool:
         """Check database connectivity by executing a simple query."""
@@ -156,11 +157,7 @@ class SQLManager(Manager[SQLConfigT], Generic[SQLConfigT, DeclarativeBaseT]):
                 impersonation=impersonation,
             ) as session:
                 await session.execute(text("SELECT 1"))
-                SuccessfulSystemOperation[
-                    OptionalAnyAuthentication,
-                    OptionalAuthorization,
-                    NoDataResponse[None],
-                ](
+                SuccessfulSystemOperation[NoDataResponse[None],](
                     application_context=self._application_context,
                     id=operation_id,
                     context=self._operation_context,
@@ -172,14 +169,10 @@ class SQLManager(Manager[SQLConfigT], Generic[SQLConfigT, DeclarativeBaseT]):
                     authorization=authorization,
                     impersonation=impersonation,
                     response=NoDataResponse[None](metadata=None, other=None),
-                ).log(
-                    self._logger, Level.INFO
-                )
+                ).log(self._logger, Level.INFO)
             return True
         except Exception as e:
-            exc = MaleoExceptionFactory[
-                OptionalAnyAuthentication, OptionalAuthorization
-            ].from_code(
+            exc = MaleoExceptionFactory.from_code(
                 ErrorCode.INTERNAL_SERVER_ERROR,
                 details={
                     "exc_type": type(e).__name__,
@@ -208,7 +201,7 @@ class SQLManager(Manager[SQLConfigT], Generic[SQLConfigT, DeclarativeBaseT]):
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ) -> bool:
         """Check database connectivity by executing a simple query."""
@@ -227,11 +220,7 @@ class SQLManager(Manager[SQLConfigT], Generic[SQLConfigT, DeclarativeBaseT]):
                 impersonation=impersonation,
             ) as session:
                 session.execute(text("SELECT 1"))
-                SuccessfulSystemOperation[
-                    OptionalAnyAuthentication,
-                    OptionalAuthorization,
-                    NoDataResponse[None],
-                ](
+                SuccessfulSystemOperation[NoDataResponse[None],](
                     application_context=self._application_context,
                     id=operation_id,
                     context=self._operation_context,
@@ -243,14 +232,10 @@ class SQLManager(Manager[SQLConfigT], Generic[SQLConfigT, DeclarativeBaseT]):
                     authorization=authorization,
                     impersonation=impersonation,
                     response=NoDataResponse[None](metadata=None, other=None),
-                ).log(
-                    self._logger, Level.INFO
-                )
+                ).log(self._logger, Level.INFO)
             return True
         except Exception as e:
-            exc = MaleoExceptionFactory[
-                OptionalAnyAuthentication, OptionalAuthorization
-            ].from_code(
+            exc = MaleoExceptionFactory.from_code(
                 ErrorCode.INTERNAL_SERVER_ERROR,
                 details={
                     "exc_type": type(e).__name__,
@@ -318,10 +303,11 @@ class NoSQLManager(
     Manager[NoSQLConfigT],
     Generic[
         NoSQLConfigT,
-        AsyncClientT,
-        SyncClientT,
+        ClientManagerT,
     ],
 ):
+    client_manager_cls: Type[ClientManagerT]
+
     def __init__(
         self,
         config: NoSQLConfigT,
@@ -330,18 +316,10 @@ class NoSQLManager(
     ) -> None:
         super().__init__(config, logger, application_context)
         self._operation_context.target.details = self._config.model_dump()
-        self._client_manager = ClientManager[
-            NoSQLConfigT,
-            AsyncClientT,
-            SyncClientT,
-        ](config)
+        self._client_manager = self.client_manager_cls(config)  # type: ignore
 
     @property
-    def client(self) -> ClientManager[
-        NoSQLConfigT,
-        AsyncClientT,
-        SyncClientT,
-    ]:
+    def client(self) -> ClientManagerT:
         return self._client_manager
 
     async def async_check_connection(
@@ -349,7 +327,7 @@ class NoSQLManager(
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ) -> bool:
         """Check client connectivity by executing a simple query."""
@@ -375,7 +353,7 @@ class NoSQLManager(
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ) -> bool:
         """Check client connectivity by executing a simple query."""
@@ -401,17 +379,17 @@ class NoSQLManager(
 
 
 class ElasticsearchManager(
-    NoSQLManager[ElasticsearchConfig, AsyncElasticsearch, Elasticsearch]
+    NoSQLManager[ElasticsearchConfig, ElasticsearchClientManager]
 ):
-    pass
+    client_manager_cls = ElasticsearchClientManager
 
 
-class MongoManager(NoSQLManager[MongoConfig, AsyncIOMotorClient, MongoClient]):
-    pass
+class MongoManager(NoSQLManager[MongoConfig, MongoClientManager]):
+    client_manager_cls = MongoClientManager
 
 
-class RedisManager(NoSQLManager[RedisConfig, AsyncRedis, SyncRedis]):
-    pass
+class RedisManager(NoSQLManager[RedisConfig, RedisClientManager]):
+    client_manager_cls = RedisClientManager
 
 
 AnyNoSQLManager = Union[
