@@ -38,7 +38,7 @@ from maleo.schemas.operation.mixins import Timestamp
 from maleo.schemas.operation.system import SuccessfulSystemOperation
 from maleo.schemas.response import NoDataResponse
 from maleo.schemas.security.authentication import OptionalAnyAuthentication
-from maleo.schemas.security.authorization import OptionalAuthorization
+from maleo.schemas.security.authorization import OptionalAnyAuthorization
 from maleo.schemas.security.impersonation import OptionalImpersonation
 from maleo.types.uuid import OptionalUUID
 from maleo.logging.enums import Level
@@ -67,7 +67,11 @@ class SessionManager(Generic[SQLConfigT]):
             origin=Origin.SERVICE,
             layer=Layer.UTILITY,
             target=Target.DATABASE,
-            target_details=self._config.model_dump(),
+            target_details=self._config.model_dump(
+                exclude={
+                    "connection": {"password"}
+                }
+            ),
         )
 
         self._async_sessionmaker: async_sessionmaker[AsyncSession] = async_sessionmaker[
@@ -82,7 +86,7 @@ class SessionManager(Generic[SQLConfigT]):
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ) -> AsyncGenerator[AsyncSession, None]:
         """Reusable function for managing async database session."""
@@ -92,9 +96,7 @@ class SessionManager(Generic[SQLConfigT]):
         )
 
         session: AsyncSession = self._async_sessionmaker()
-        SuccessfulSystemOperation[
-            OptionalAnyAuthentication, OptionalAuthorization, NoDataResponse[None]
-        ](
+        SuccessfulSystemOperation[NoDataResponse[None]](
             application_context=self._application_context,
             id=operation_id,
             context=self._operation_context,
@@ -106,9 +108,7 @@ class SessionManager(Generic[SQLConfigT]):
             authorization=authorization,
             impersonation=impersonation,
             response=NoDataResponse[None](metadata=None, other=None),
-        ).log(
-            self._logger, level=Level.DEBUG
-        )
+        ).log(self._logger, level=Level.DEBUG)
 
         executed_at = datetime.now(tz=timezone.utc)
 
@@ -116,9 +116,7 @@ class SessionManager(Generic[SQLConfigT]):
             # explicit transaction context — will commit on success, rollback on exception
             async with session.begin():
                 yield session
-            SuccessfulSystemOperation[
-                OptionalAnyAuthentication, OptionalAuthorization, NoDataResponse[None]
-            ](
+            SuccessfulSystemOperation[NoDataResponse[None]](
                 application_context=self._application_context,
                 id=operation_id,
                 context=self._operation_context,
@@ -130,14 +128,10 @@ class SessionManager(Generic[SQLConfigT]):
                 authorization=authorization,
                 impersonation=impersonation,
                 response=NoDataResponse[None](metadata=None, other=None),
-            ).log(
-                self._logger, level=Level.INFO
-            )
+            ).log(self._logger, level=Level.INFO)
         except SQLAlchemyError as se:
             await session.rollback()
-            exc = MaleoExceptionFactory[
-                OptionalAnyAuthentication, OptionalAuthorization
-            ].from_code(
+            exc = MaleoExceptionFactory.from_code(
                 ErrorCode.INTERNAL_SERVER_ERROR,
                 details={
                     "exc_type": type(se).__name__,
@@ -162,9 +156,7 @@ class SessionManager(Generic[SQLConfigT]):
             raise exc from se
         except ValidationError as ve:
             await session.rollback()
-            exc = MaleoExceptionFactory[
-                OptionalAnyAuthentication, OptionalAuthorization
-            ].from_code(
+            exc = MaleoExceptionFactory.from_code(
                 ErrorCode.UNPROCESSABLE_ENTITY,
                 details=ve.errors(),
                 operation_type=OperationType.SYSTEM,
@@ -186,9 +178,7 @@ class SessionManager(Generic[SQLConfigT]):
             raise
         except Exception as e:
             await session.rollback()
-            exc = MaleoExceptionFactory[
-                OptionalAnyAuthentication, OptionalAuthorization
-            ].from_code(
+            exc = MaleoExceptionFactory.from_code(
                 ErrorCode.INTERNAL_SERVER_ERROR,
                 details={
                     "exc_type": type(e).__name__,
@@ -213,9 +203,7 @@ class SessionManager(Generic[SQLConfigT]):
             raise exc from e
         finally:
             await session.close()
-            SuccessfulSystemOperation[
-                OptionalAnyAuthentication, OptionalAuthorization, NoDataResponse[None]
-            ](
+            SuccessfulSystemOperation[NoDataResponse[None]](
                 application_context=self._application_context,
                 id=operation_id,
                 context=self._operation_context,
@@ -227,16 +215,14 @@ class SessionManager(Generic[SQLConfigT]):
                 authorization=authorization,
                 impersonation=impersonation,
                 response=NoDataResponse[None](metadata=None, other=None),
-            ).log(
-                self._logger, level=Level.INFO
-            )
+            ).log(self._logger, level=Level.INFO)
 
     def _sync_session_handler(
         self,
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ) -> Generator[Session, None, None]:
         """Reusable function for managing sync database session."""
@@ -246,9 +232,7 @@ class SessionManager(Generic[SQLConfigT]):
         )
 
         session: Session = self._sync_sessionmaker()
-        SuccessfulSystemOperation[
-            OptionalAnyAuthentication, OptionalAuthorization, NoDataResponse[None]
-        ](
+        SuccessfulSystemOperation[NoDataResponse[None]](
             application_context=self._application_context,
             id=operation_id,
             context=self._operation_context,
@@ -260,9 +244,7 @@ class SessionManager(Generic[SQLConfigT]):
             authorization=authorization,
             impersonation=impersonation,
             response=NoDataResponse[None](metadata=None, other=None),
-        ).log(
-            self._logger, level=Level.DEBUG
-        )
+        ).log(self._logger, level=Level.DEBUG)
 
         executed_at = datetime.now(tz=timezone.utc)
 
@@ -270,9 +252,7 @@ class SessionManager(Generic[SQLConfigT]):
             # explicit transaction context — will commit on success, rollback on exception
             with session.begin():
                 yield session
-            SuccessfulSystemOperation[
-                OptionalAnyAuthentication, OptionalAuthorization, NoDataResponse[None]
-            ](
+            SuccessfulSystemOperation[NoDataResponse[None]](
                 application_context=self._application_context,
                 id=operation_id,
                 context=self._operation_context,
@@ -284,14 +264,10 @@ class SessionManager(Generic[SQLConfigT]):
                 authorization=authorization,
                 impersonation=impersonation,
                 response=NoDataResponse[None](metadata=None, other=None),
-            ).log(
-                self._logger, level=Level.INFO
-            )
+            ).log(self._logger, level=Level.INFO)
         except SQLAlchemyError as se:
             session.rollback()  # Rollback on error
-            exc = MaleoExceptionFactory[
-                OptionalAnyAuthentication, OptionalAuthorization
-            ].from_code(
+            exc = MaleoExceptionFactory.from_code(
                 ErrorCode.INTERNAL_SERVER_ERROR,
                 details={
                     "exc_type": type(se).__name__,
@@ -316,9 +292,7 @@ class SessionManager(Generic[SQLConfigT]):
             raise exc from se
         except ValidationError as ve:
             session.rollback()  # Rollback on error
-            exc = MaleoExceptionFactory[
-                OptionalAnyAuthentication, OptionalAuthorization
-            ].from_code(
+            exc = MaleoExceptionFactory.from_code(
                 ErrorCode.UNPROCESSABLE_ENTITY,
                 details=ve.errors(),
                 operation_type=OperationType.SYSTEM,
@@ -340,9 +314,7 @@ class SessionManager(Generic[SQLConfigT]):
             raise
         except Exception as e:
             session.rollback()  # Rollback on error
-            exc = MaleoExceptionFactory[
-                OptionalAnyAuthentication, OptionalAuthorization
-            ].from_code(
+            exc = MaleoExceptionFactory.from_code(
                 ErrorCode.INTERNAL_SERVER_ERROR,
                 details={
                     "exc_type": type(e).__name__,
@@ -367,9 +339,7 @@ class SessionManager(Generic[SQLConfigT]):
             raise exc from e
         finally:
             session.close()  # Ensure session closes
-            SuccessfulSystemOperation[
-                OptionalAnyAuthentication, OptionalAuthorization, NoDataResponse[None]
-            ](
+            SuccessfulSystemOperation[NoDataResponse[None]](
                 application_context=self._application_context,
                 id=operation_id,
                 context=self._operation_context,
@@ -381,9 +351,7 @@ class SessionManager(Generic[SQLConfigT]):
                 authorization=authorization,
                 impersonation=impersonation,
                 response=NoDataResponse[None](metadata=None, other=None),
-            ).log(
-                self._logger, level=Level.INFO
-            )
+            ).log(self._logger, level=Level.INFO)
 
     @asynccontextmanager
     async def _async_context_manager(
@@ -391,7 +359,7 @@ class SessionManager(Generic[SQLConfigT]):
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ) -> AsyncGenerator[AsyncSession, None]:
         """Async context manager implementation."""
@@ -410,7 +378,7 @@ class SessionManager(Generic[SQLConfigT]):
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ) -> Generator[Session, None, None]:
         """Sync context manager implementation."""
@@ -430,7 +398,7 @@ class SessionManager(Generic[SQLConfigT]):
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ) -> AbstractAsyncContextManager[AsyncSession]: ...
 
@@ -441,7 +409,7 @@ class SessionManager(Generic[SQLConfigT]):
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ) -> AbstractContextManager[Session]: ...
 
@@ -451,7 +419,7 @@ class SessionManager(Generic[SQLConfigT]):
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ) -> Union[
         AbstractAsyncContextManager[AsyncSession], AbstractContextManager[Session]
@@ -483,7 +451,7 @@ class SessionManager(Generic[SQLConfigT]):
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ) -> AsyncGenerator[AsyncSession, None]:
         """Explicit async context manager."""
@@ -500,7 +468,7 @@ class SessionManager(Generic[SQLConfigT]):
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ) -> Generator[Session, None, None]:
         """Explicit sync context manager."""
@@ -515,7 +483,7 @@ class SessionManager(Generic[SQLConfigT]):
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ):
         """Explicit async dependency injection."""
@@ -536,7 +504,7 @@ class SessionManager(Generic[SQLConfigT]):
         operation_id: OptionalUUID = None,
         connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAuthorization = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
     ):
         """Explicit sync dependency injection."""
