@@ -6,13 +6,13 @@ from sqlalchemy.types import Integer, Enum, TIMESTAMP
 from uuid import UUID as PythonUUID, uuid4
 from maleo.enums.status import DataStatus as DataStatusEnum
 from maleo.types.datetime import OptionalDatetime
-from maleo.utils.formatters.case import to_snake
+from maleo.utils.formatter import CaseFormatter
 
 
 class TableName:
     @declared_attr.directive
     def __tablename__(cls) -> str:
-        return to_snake(cls.__name__)  # type: ignore
+        return CaseFormatter.to_snake(cls.__name__)  # type: ignore
 
 
 class DataIdentifier:
